/**
 * @file ps2gamelite.h
 *
 * @author Andy Lindsay
 *
 * @version 0.1
 *
 * @copyright
 * Copyright (C) Parallax, Inc. 2015. All Rights MIT Licensed.
 *
 * @brief Communicate with PlayStation 2 controller(s) and return
 * button and joystick data.
 */

#ifndef PS2LITE_H
#define PS2LITE_H

#if defined(__cplusplus)
extern "C" {
#endif


#include "simpletools.h"

typedef struct ps2game_st{
  volatile int dat;
  volatile int cmd;
  volatile int att;
  volatile int clk;
  volatile int thumbL;
  volatile int thumbR;
  volatile int status;
  volatile int joyRX;
  volatile int joyRY;
  volatile int joyLX;
  volatile int joyLY;
  volatile int set;
  volatile int byteCount;
  volatile int *array;
  volatile int cog; 
           int stack[128];
} ps2game_t; 

//extern volatile int enterEscape[9];
//extern volatile int setAnalogMode[9];
//extern volatile int exitEscape[9];
 

int ps2game_setAnalog(ps2game_t *device); 

/**
 * @brief Open a ps2game device.
 *
 * @param dat number of pin connected to dat line.
 * @param cmd number of pin connected to cmd line.
 * @param att number of pin connected to att line.
 * @param clk number of pin connected to clk line.
 *
 * @returns Game controller process identifier for use with other functions.
 */
ps2game_t *ps2game_open(int dat, int cmd, int att, int clk);


/**
 * @brief Close a ps2game device, and recover cog, and memory.
 *
 * @param *device process ID returned by ps2game_open.
 */
void ps2game_close(ps2game_t *device);


/**
 * @brief Check connection status.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns status 90 (0x5a) if connected.
 */
int ps2game_status(ps2game_t *device);


/**
 * @brief Check square button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_square(ps2game_t *device);


/**
 * @brief Check cross button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_cross(ps2game_t *device);


/**
 * @brief Check circle button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_circle(ps2game_t *device);


/**
 * @brief Check triangle button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_triangle(ps2game_t *device);


/**
 * @brief Check upper-right-front button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_1R(ps2game_t *device);


/**
 * @brief Check upper-left-front button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_1L(ps2game_t *device);


/**
 * @brief Check lower-right-front button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_2R(ps2game_t *device);


/**
 * @brief Check lower-left-front button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_2L(ps2game_t *device);


/**
 * @brief Check left arrow button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_left(ps2game_t *device);


/**
 * @brief Check backward arrow button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_backward(ps2game_t *device);


/**
 * @brief Check right arrow button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_right(ps2game_t *device);


/**
 * @brief Check forward arrow button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_forward(ps2game_t *device);


/**
 * @brief Check start button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_start(ps2game_t *device);


/**
 * @brief Check select button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_select(ps2game_t *device);


/**
 * @brief Check left joystick button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_joyPressL(ps2game_t *device);


/**
 * @brief Check right joystick button.
 *
 * @param *device process ID returned by ps2game_open.
 *
 * @returns 1 if pressed, 0 if not pressed.
 */
int ps2game_joyPressR(ps2game_t *device);


/**
 * @brief Check left joystick x-axis.
 *
 * @param *device  process ID returned by ps2game_open.
 *
 * @returns 0(far left)...128(center)...255(far right).
 */
int ps2game_joyLX(ps2game_t *device);


/**
 * @brief Check left joystick y-axis.
 *
 * @param *device  process ID returned by ps2game_open.
 *
 * @returns 0(all the way forward)...128(center)...255(all the way back).
 */
int ps2game_joyLY(ps2game_t *device);


/**
 * @brief Check right joystick x-axis.
 *
 * @param *device  process ID returned by ps2game_open.
 *
 * @returns 0(far left)...128(center)...255(far right).
 */
int ps2game_joyRX(ps2game_t *device);


/**
 * @brief Check right joystick y-axis.
 *
 * @param *device  process ID returned by ps2game_open.
 *
 * @returns 0(all the way forward)...128(center)...255(all the way back).
 */
int ps2game_joyRY(ps2game_t *device);


#if defined(__cplusplus)
}
#endif
/* __cplusplus */ 
#endif
/* PS2LITE_H */ 


/**
* TERMS OF USE: MIT License
*
* Permission is hereby granted, free of charge, to any person obtaining a
* copy of this software and associated documentation files (the "Software"),
* to deal in the Software without restriction, including without limitation
* the rights to use, copy, modify, merge, publish, distribute, sublicense,
* and/or sell copies of the Software, and to permit persons to whom the
* Software is furnished to do so, subject to the following conditions:
*
* The above copyright notice and this permission notice shall be included in
* all copies or substantial portions of the Software.
*
* THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
* IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
* FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
* THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
* LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
* FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
* DEALINGS IN THE SOFTWARE.
*/

